@@ -38,6 +38,11 @@ class DataFrameLoader(BaseLoader):
             default_value=None,
             description="Whether to drop duplicates in certain columns. ('column', or ['col_a', 'col_b'])",
         ),
+        "compute_ddf": Field(
+            bool,
+            default_value=False,
+            description="Whether to compute the dask dataframe.",
+        ),
         "load_params": Field(
             Permissive({}),
             description="Extra parameters that get passed to the loading function.",
@@ -49,6 +54,7 @@ class DataFrameLoader(BaseLoader):
         df: Union[pd.DataFrame, dd.DataFrame],
         drop_na: List[str],
         drop_duplicates: List[str],
+        compute_ddf: bool,
     ):
         """
         This function post processes the dataframe after loading
@@ -60,6 +66,9 @@ class DataFrameLoader(BaseLoader):
         if drop_duplicates:
             df = df.drop_duplicates(subset=drop_duplicates)
 
+        if compute_ddf:
+            df = df.compute()
+
         return df
 
     @classmethod
@@ -70,6 +79,7 @@ class DataFrameLoader(BaseLoader):
         repartitions: int = None,
         drop_na: List[str] = None,
         drop_duplicates: List[str] = None,
+        compute_ddf: bool = False,
         load_params: Dict[str, Any] = {},
     ) -> Union[pd.DataFrame, dd.DataFrame]:
         # Choose which framework to use for loading the data
@@ -131,6 +141,7 @@ class DataFrameLoader(BaseLoader):
             df,
             drop_na=drop_na,
             drop_duplicates=drop_duplicates,
+            compute_ddf=compute_ddf,
         )
 
         return df
