@@ -8,7 +8,7 @@ from qdk.loader.base import BaseLoader
 
 class S3PickleLoader(BaseLoader):
     output_defs = [
-        OutputDefinition(Any, "output"),
+        OutputDefinition(Any, "result"),
     ]
 
     config_schema = {
