@@ -1,6 +1,7 @@
 from dask.array.core import Array as DaskArray
 from dask.dataframe import DataFrame as DaskDataFrame
 from dask.dataframe import Series as DaskSeries
+from gensim.models.word2vec import Word2Vec
 from numpy import ndarray
 from pandas import DataFrame, Series
 from qdk.mlflow import MLFlowRun
@@ -50,7 +51,11 @@ def is_dask_dataframe(value):
 
 
 def is_model(value):
-    return isinstance(value, BaseEstimator) or isinstance(value, MLFlowRun)
+    return (
+        isinstance(value, BaseEstimator)
+        or isinstance(value, Word2Vec)
+        or isinstance(value, MLFlowRun)
+    )
 
 
 def is_mlflow_run(value):
